function [t_lefts,t_rights,conv_psth] = find_burst_duration(psth,t_peaks,min_activity)
% Function to detect the bursts' edges (start and stop). Convolution with a
% Gaussian window is used to smooth the PSTH. Start and stop are defined as
% the first zero points before and after the peak of the burst. This
% function works only if PSTH is calculated with 1ms bin.
% 
% Rocco Pulizzi
% 21/04/2015

conv_window = 100; % Window size (ms), NOTE: Burst durations below conv_window are problematic
gauss_window = gausswin(conv_window)/sum(gausswin(conv_window));
conv_psth = conv(psth,gauss_window,'same');

t_lefts = nan(size(t_peaks)); t_rights = t_lefts;
for i = 1:length(t_peaks)
    % min_activity = activity_drop*a_peaks(i);
    % Detecting starting edge
    start_flag = 1; start_bin = 0;
    while start_flag
        start_bin = start_bin + 1;
        if t_peaks(i)-start_bin > 0
            if conv_psth(t_peaks(i)-start_bin) <= min_activity
                start_flag  = 0; t_lefts(i) = t_peaks(i)-start_bin+round(conv_window/2);
            end
        else
            start_flag = 0; t_lefts(i)	= 1;
        end
    end
    % Detecting stopping edge
    stop_flag = 1; stop_bin = 0;
    while stop_flag
        stop_bin = stop_bin + 1;
        if t_peaks(i)+stop_bin < length(conv_psth)
            if conv_psth(t_peaks(i)+stop_bin) <= min_activity
                if t_peaks(i)+stop_bin+dead_time-1 < length(conv_psth)
                    perc_below = sum(conv_psth(t_peaks(i)+stop_bin:t_peaks(i)+stop_bin+dead_time-1) <= min_activity)/dead_time; % Percentage of data points in dead_time window that are below threshold
                else
                    perc_below = sum(conv_psth(t_peaks(i)+stop_bin:end) <= min_activity)/(length(conv_psth)-(t_peaks(i)+stop_bin)+1); % Percentage of data points in dead_time window that are below threshold
                end
                if perc_below >= dead_fraction/100
                    stop_flag = 0; t_rights(i) = t_peaks(i)+stop_bin-round(conv_window/2);
                end
            end
        else
            stop_flag = 0; t_rights(i) = length(conv_psth);
        end
    end
end

