function [c, lag, significant, t, f] = pairwise_cc(chan1,chan2,spikes,Tmax,bin,MinSP)%,box_wind)
%
% [c lag significant] = final_pairwise_cc(chan1, chan2)
%
% This function assumes the (global) structure 'spikes' has been 
% loaded and computes (if enough spikes are present in the specified 
% pair - i.e. > 150) the peak cross-correlogram and its significance.
%
%
% NOTE: it assumes that spike times are in ms !!!!
%
% Jan 24th 2010 - Michele Giugliano, mgiugliano@gmail.com
% Jul 29th 2015 - Rocco Pulizzi, rocco.plz@gmail.com
%

if ~exist('bin','var'); bin = 3; end

% Let's take out from 'spikes' only the two spike-trains we want
sp1   = spikes(spikes(:,2)==chan1,1);
sp2   = spikes(spikes(:,2)==chan2,1);
N1    = length(sp1);
N2    = length(sp2);

% First test on the significance of the cross-correlation;
if ( (N1 < MinSP) || (N2 < MinSP) || (N1 > 100000) || (N2 > 100000) )
 c           = nan;
 lag         = nan;
 significant = nan;
 t           = nan;
 f           = nan;
 return; 
end;

% Let's compute all the possible time-differences between spike pair
index = 0;
for i=1:N1,
 k = find( abs(sp1(i) - sp2) <= Tmax );     % speed-up trick!
 index = index + length(k);
end
clear k 
D = zeros(1,index);

index = 0;
for i=1:N1,
 k = find( abs(sp1(i) - sp2) <= Tmax );     % speed-up trick!
 for j=1:length(k),
  index = index + 1;
  D(index) = sp2(k(j)) - sp1(i);
 end
end
clear k index

x = -Tmax:bin:Tmax;

f = histc(D,x);
f(Tmax) = f(Tmax) + sum(D == 0); % Histc works asymmetrically (including left but not right border of bin) -> Delays of exactly 0 belong to both negative & positive time lag (Only necessary when positive vs negative time lags are split out to both sides of CC matrix)
f(end-1) = f(end-1)+f(end); f(end) = []; % Correction due to way histc works (last bin is only a border by itself)
t = x(1:end-1) + bin/2; % Results from histogram count belong to middle of bin, not left border
f = f/sqrt(N1*N2); % Normalisation

% Computing the probability density estimate of the time-differences between spike pair
% [f, x, ~] = ksdensity(D, 'kernel', 'box', 'width', box_wind);


% Let's compute the same quantity, from surrogate data..
nr_bootstrap = 500;
Ns = nan(nr_bootstrap,length(t));
for k=1:500,
 Ds = D + 30 * randn(size(D)); % Add random delays to the actual delays, ranging from approx. -100 to +100
 fs = histc(Ds,x);
 fs(end-1) = fs(end-1)+fs(end); fs(end) = [];
 fs = fs/sqrt(N1*N2); % Normalisation
 % [fs, ~, ~] = ksdensity(Ds, 'kernel', 'box', 'width', box_wind);
 Ns(k,:) = fs;
 clear fs Ds
end
mNs = mean(Ns);                             % Mean and
sNs = std(Ns);                              % standard deviation

clear NS Ds

% The output of the routine!
c = max(f);                                 % Peak of the CC
h = find(f == c);                           %
h = h(1);                                   % Index of the lag on 'x'       -> Why randomly picking first maximum?
lag = t(h);                                 % Lag of the CC peak [ms]

significant = (c > (mNs(h) + 3 * sNs(h)) ); % == 1 if peak CC > 3 times the standard deviation

% Final test for significance
if c*sqrt(N1*N2) <= 15 % At least 15 spike counts at tau of max C peak
 c           = nan;
 lag         = nan;
 significant = nan;
 t           = nan;
 f           = nan;
end

clear h k mNs sNS D N1 N2 sp1 sp2 Tmax box_wind nr_points bin_size
