function [fig,ax] = populated_fig(size,margin,interspacing,dim,uneven_nr_plots)
% This function generates a figure with a total of dim(1)*dim(2) axes,
% spaced by margins from the edges and from each other by interspacing.
% margin, interspacing and dim expect 2x1 vectors specifying x and y
% values. In case of an uneven number of plots (uneven_nr_plots = 1), the
% last axis is omitted.
%
% Sebastiaan Van De Vijver

plt_size = [(1-2*margin(1)-(dim(1)-1)*interspacing(1))/dim(1) (1-2*margin(2)-(dim(2)-1)*interspacing(2))/dim(2)]; % Height and width of each sub-plot
layout = reshape(1:prod(dim),dim(1),dim(2))'; % Populate plots from top left to bottom right, left to right then top to bottom (remove ' for top to bottom then left to right)
set(0,'DefaultAxesFontSize',10,'DefaultTextFontSize',10,'DefaultAxesFontName','Tahoma','DefaultTextFontName','Tahoma','DefaultTextVerticalAlignment','bottom','DefaultTextHorizontalAlignment','left');
fig = figure('PaperUnits','centimeters'); ax = zeros(prod(dim));
set(fig,'Color','w','PaperPosition',[0.1 0 size(1) size(2)],'PaperSize',[size(1) size(2)]);
for i = 1:prod(dim)-uneven_nr_plots
    [y,loc] = find(i == layout); y = dim(2) + 1 - y; % Going from matrix coordinate system to plot coordinate system
    ax(i) = axes('Position',[margin(1) + (loc-1)*(interspacing(1) + plt_size(1)), margin(2) + (y-1)*(interspacing(2) + plt_size(2)), plt_size(1), plt_size(2)],...
        'xcolor','k','ycolor','k','color','none','box','off','YAxisLocation','left','LineWidth',1,'Tickdir','out');
end

end